using System;
using System.Collections;
using System.ComponentModel;
using System.Drawing;
using System.Diagnostics;
using System.Data;
using System.Windows.Forms;
using Microsoft.DataTransformationServices.Controls;
using Microsoft.SqlServer.Dts.Design;
using Microsoft.SqlServer.Dts.Runtime;
using SSIS2K5.Samples.Tasks.CryptoTask;

namespace SSIS2K5.Samples.Tasks.CryptoTask
{
   #region GeneralView
   public partial class GeneralView : System.Windows.Forms.UserControl, IDTSTaskUIView
   {
		#region private members
		private GeneralNode generalNode = null;
      
		private System.Windows.Forms.PropertyGrid generalPropertyGrid;
      private CryptoTask theTask = null;
        /// <summary> 
		/// Required designer variable.
		/// </summary>
		private System.ComponentModel.Container components = null;
		#endregion private members

		#region Init and Dispose
		public GeneralView()
		{
			// This call is required by the Windows.Forms Form Designer.
			InitializeComponent();
		}

		/// <summary> 
		/// Clean up any resources being used.
		/// </summary>
		protected override void Dispose( bool disposing )
		{
			if( disposing )
			{
				if(components != null)
				{
					components.Dispose();
				}
			}
			base.Dispose( disposing );
		}
		#endregion Init and Dispose

		#region IDTSTaskUIView
		/// <summary>
		/// Called when the view is about to be displayed for the first time
		/// </summary>
		/// <param name="treeHost">IDTSTaskUIHost that host the view</param>
		/// <param name="taskHost">the task that is edited by TaskUI</param>
		/// <param name="viewNode">the node in the tree associated with this view</param>
		public virtual void OnInitialize(IDTSTaskUIHost treeHost, System.Windows.Forms.TreeNode viewNode, object taskHost, object connections)
		{
         if (taskHost == null)
         {
            throw new ArgumentNullException("Attempting to initialize the CryptoTask UI with a null TaskHost");
         }

         if (!(((TaskHost)taskHost).InnerObject is CryptoTask))
         {
            throw new ArgumentException("Attempting to initialize the CryptoTask UI with a task that is not a CryptoTask.");
         }

         theTask = ((TaskHost)taskHost).InnerObject as CryptoTask;

			this.generalNode = new GeneralNode(taskHost as TaskHost);

			generalPropertyGrid.SelectedObject = this.generalNode;
		}

		/// <summary>
		/// is called when the OK button is pressed
		/// </summary>
		/// <param name="bViewIsValid">result of view validation</param>
		public virtual void OnValidate(ref bool bViewIsValid, ref string reason)
		{
		}

		/// <summary>
		/// called whenever the view is displaying
		/// </summary>
		public virtual void OnSelection()
		{
		}

		/// <summary>
		/// called every time the view is about to be left.
		/// </summary>
		/// <param name="bCanLeaveView">true if the view can be left</param>
		public virtual void OnLoseSelection(ref bool bCanLeaveView, ref string reason)
		{
		}

		/// <summary>
		/// called when OK button is pushed, but only if all OnValidate calls succeeded
		/// the user should set whatever properties need to be set to the task by this view
		/// </summary>
		/// <param name="taskHost">the edited task.</param>
		public virtual void OnCommit(object taskHost)
		{
			TaskHost th = (TaskHost)taskHost;

         // Write out the name and description entered.
         th.Name =  generalNode.Name.Trim();
         th.Description = generalNode.Description.Trim();
		}
		#endregion IDTSTaskUIView

		#region Component Designer generated code
		/// <summary> 
		/// Required method for Designer support - do not modify 
		/// the contents of this method with the code editor.
		/// </summary>
		private void InitializeComponent()
		{
         this.generalPropertyGrid = new System.Windows.Forms.PropertyGrid();
         this.SuspendLayout();
         // 
         // generalPropertyGrid
         // 
         this.generalPropertyGrid.Anchor = ((System.Windows.Forms.AnchorStyles)((((System.Windows.Forms.AnchorStyles.Top | System.Windows.Forms.AnchorStyles.Bottom)
                     | System.Windows.Forms.AnchorStyles.Left)
                     | System.Windows.Forms.AnchorStyles.Right)));
         this.generalPropertyGrid.Location = new System.Drawing.Point(3, 0);
         this.generalPropertyGrid.Name = "generalPropertyGrid";
         this.generalPropertyGrid.PropertySort = System.Windows.Forms.PropertySort.Categorized;
         this.generalPropertyGrid.Size = new System.Drawing.Size(387, 360);
         this.generalPropertyGrid.TabIndex = 0;
         this.generalPropertyGrid.ToolbarVisible = false;
         // 
         // GeneralView
         // 
         this.Controls.Add(this.generalPropertyGrid);
         this.Name = "GeneralView";
         this.Size = new System.Drawing.Size(390, 360);
         this.ResumeLayout(false);

      }
      #endregion
   }
   #endregion
   
	#region GeneralNode

	/// <summary>
	/// General Node class corresponds to the view that is displayed when
	/// the user clicks the General node.
	/// </summary>
	internal class GeneralNode
	{
		internal TaskHost taskHost= null;
		private SSIS2K5.Samples.Tasks.CryptoTask.CryptoTask task = null;

		#region Initialization

		public GeneralNode(TaskHost taskHost)
		{
			this.taskHost = taskHost;
			this.task = taskHost.InnerObject as SSIS2K5.Samples.Tasks.CryptoTask.CryptoTask;
		}

		#endregion

		#region GeneralNodeProperties

		[
		Category("General"),
		Description("Specifies the name of the task.")
		]
		public string Name
		{
			get { return taskHost.Name; }
			set
			{
				if ((value == null) || (value.Trim().Length == 0))
				{
					throw new ApplicationException("Task name cannot be empty");
				}

				taskHost.Name = value;
			}
		}

		[
		Category("General"),
		Description("Specifies the description for this task.")
		]
		public string Description
		{
			get { return taskHost.Description; }
			set { taskHost.Description = value; }
		}

		#endregion GeneralNodeProperties
	}

	#endregion GeneralNode

}
