using System;
using System.Xml;
using System.Collections;
using System.ComponentModel;
using System.Diagnostics;
using System.Drawing;
using System.Windows.Forms;
using System.Resources;
using Microsoft.DataTransformationServices.Controls;
using Microsoft.SqlServer.Dts.Runtime;
using SSIS2K5.Samples.Tasks.ExpressionTask;

namespace SSIS2K5.Samples.Tasks.ExpressionTask
{
	/// <summary>
	/// This class implements the functionality for the Main Form
	/// </summary>
	public class ExpressionTaskMainWnd : DTSBaseTaskUI
	{
		private const string Title = "Expression Task Editor";
		private const string Description = "This task is used to evaluate an expression.";
      public static Icon taskIcon = new Icon(typeof(SSIS2K5.Samples.Tasks.ExpressionTask.ExpressionTask), "TaskIcon.ico");
     
		#region private members
		private SSIS2K5.Samples.Tasks.ExpressionTask.ExpressionTask expressionTask = null;
		XmlElement backupXml = null;
		#endregion private members

		#region init and construct
		public ExpressionTaskMainWnd( TaskHost taskHost, object connections) :
			base(Title, taskIcon, Description, taskHost, connections)
		{
			Debug.Assert( taskHost != null );

			//Create the view that will expose in the UI the task properties
			GeneralView generalView = new GeneralView();
			
			// Add the view to the main form
			this.DTSTaskUIHost.AddView("General", generalView, null);

			BackupTask(taskHost);
		}

		/// <summary>
		/// Creates a copy of the task XML to restore the task when Cancel button is pressed
		/// </summary>
		/// <param name="taskHost"></param>
		private void BackupTask(TaskHost taskHost)
		{
			if( taskHost == null )
				return;

			this.expressionTask = taskHost.InnerObject as Tasks.ExpressionTask.ExpressionTask;


			XmlDocument doc  = new XmlDocument();
			expressionTask.SaveToXML( doc, null );
			backupXml = doc.DocumentElement;
		}

		/// <summary>
		/// Clean up any resources being used.
		/// </summary>
		protected override void Dispose( bool disposing )
		{
			base.Dispose( disposing );
		}
		#endregion init and construct

		#region overriden function
		/// <summary>
		/// This method is called whenever the dialog is closing
		/// </summary>
		/// <param name="e"></param>
		protected override void OnClosing(System.ComponentModel.CancelEventArgs e)
		{
			//If the dialog was not dismissed with OK
			if( this.DialogResult != DialogResult.OK )
			{
				//Let's restore the task
				if( expressionTask != null )
				{
					expressionTask.LoadFromXML( backupXml, null );
				}
			}
		}

		protected override void OnCancel(object sender, System.EventArgs e)
		{
			this.Close();
		}
		#endregion overriden function
	}
}
