using System;
using System.Drawing;
using System.Collections;
using System.ComponentModel;
using System.Windows.Forms;
using Microsoft.SqlServer.Dts.Runtime;
using Microsoft.DataTransformationServices.Controls;
 	
namespace SSIS2K5.Samples.Tasks.ExpressionTask
{
	/// <summary>
	/// The definition for the form for editing the ExpressionTask
	/// </summary>
	public class ExpressionUIWnd : System.Windows.Forms.Form
	{
		#region controls and private members
		
		private System.Windows.Forms.Button btnCancel;
		private System.Windows.Forms.TextBox tbExpression;
		private System.Windows.Forms.Button btnValidate;
		private System.Windows.Forms.Label sMessage;
		private Microsoft.DataTransformationServices.Controls.BaseExpressionBuilderControl baseExpressionBuilderControl1;
		private System.Windows.Forms.Label label1;
		private System.Windows.Forms.Button btnOK;

		/// <summary>
		/// Required designer variable.
		/// </summary>
		private System.ComponentModel.Container components = null;

		private SSIS2K5.Samples.Tasks.ExpressionTask.ExpressionTask expressionTask;
		private TaskHost taskHost;

		#endregion controls and private members

		#region initialize and dispose methods
		public ExpressionUIWnd(TaskHost taskHost)
		{
			//
			// Required for Windows Form Designer support
			//
			this.taskHost = taskHost;
			InitializeComponent();

			this.expressionTask = taskHost.InnerObject as SSIS2K5.Samples.Tasks.ExpressionTask.ExpressionTask;
			this.tbExpression.Text = expressionTask.Expression;
			
			//Let's tell to the control containing functions to initialize itself
			this.baseExpressionBuilderControl1.InitializeTrees(taskHost.Variables);
		}

		public ExpressionUIWnd()
		{
			//
			// Required for Windows Form Designer support
			//
			InitializeComponent();
		}

		/// <summary>
		/// Clean up any resources being used.
		/// </summary>
		protected override void Dispose(bool disposing)
		{
			if (disposing)
			{
				if (components != null)
				{
					components.Dispose();
				}
			}
			base.Dispose(disposing);
		}

		#endregion initialize and dispose methods

		#region Windows Form Designer generated code
		/// <summary>
		/// Required method for Designer support - do not modify
		/// the contents of this method with the code editor.
		/// </summary>
		private void InitializeComponent()
		{
			System.ComponentModel.ComponentResourceManager resources = new System.ComponentModel.ComponentResourceManager(typeof(ExpressionUIWnd));
			this.btnOK = new System.Windows.Forms.Button();
			this.btnCancel = new System.Windows.Forms.Button();
			this.btnValidate = new System.Windows.Forms.Button();
			this.label1 = new System.Windows.Forms.Label();
			this.tbExpression = new System.Windows.Forms.TextBox();
			this.sMessage = new System.Windows.Forms.Label();
			this.baseExpressionBuilderControl1 = new Microsoft.DataTransformationServices.Controls.BaseExpressionBuilderControl();
			this.SuspendLayout();
			// 
			// btnOK
			// 
			resources.ApplyResources(this.btnOK, "btnOK");
			this.btnOK.DialogResult = System.Windows.Forms.DialogResult.OK;
			this.btnOK.Name = "btnOK";
			this.btnOK.Click += new System.EventHandler(this.btnOK_Click);
			// 
			// btnCancel
			// 
			resources.ApplyResources(this.btnCancel, "btnCancel");
			this.btnCancel.DialogResult = System.Windows.Forms.DialogResult.Cancel;
			this.btnCancel.Name = "btnCancel";
			// 
			// btnValidate
			// 
			resources.ApplyResources(this.btnValidate, "btnValidate");
			this.btnValidate.Name = "btnValidate";
			this.btnValidate.Click += new System.EventHandler(this.btnEvaluate_Click);
			// 
			// label1
			// 
			resources.ApplyResources(this.label1, "label1");
			this.label1.Name = "label1";
			// 
			// tbExpression
			// 
			this.tbExpression.AllowDrop = true;
			resources.ApplyResources(this.tbExpression, "tbExpression");
			this.tbExpression.Name = "tbExpression";
			this.tbExpression.DragOver += new System.Windows.Forms.DragEventHandler(this.tbExpression_DragOver);
			this.tbExpression.DragDrop += new System.Windows.Forms.DragEventHandler(this.tbExpression_DragDrop);
			this.tbExpression.DragEnter += new System.Windows.Forms.DragEventHandler(this.tbExpression_DragEnter);
			// 
			// sMessage
			// 
			resources.ApplyResources(this.sMessage, "sMessage");
			this.sMessage.BorderStyle = System.Windows.Forms.BorderStyle.Fixed3D;
			this.sMessage.Name = "sMessage";
			// 
			// baseExpressionBuilderControl1
			// 
			resources.ApplyResources(this.baseExpressionBuilderControl1, "baseExpressionBuilderControl1");
			this.baseExpressionBuilderControl1.Name = "baseExpressionBuilderControl1";
			// 
			// ExpressionUIWnd
			// 
			this.AcceptButton = this.btnOK;
			resources.ApplyResources(this, "$this");
			this.CancelButton = this.btnCancel;
			this.Controls.Add(this.btnValidate);
			this.Controls.Add(this.baseExpressionBuilderControl1);
			this.Controls.Add(this.label1);
			this.Controls.Add(this.tbExpression);
			this.Controls.Add(this.sMessage);
			this.Controls.Add(this.btnCancel);
			this.Controls.Add(this.btnOK);
			this.MinimizeBox = false;
			this.Name = "ExpressionUIWnd";
			this.ShowInTaskbar = false;
			this.SizeGripStyle = System.Windows.Forms.SizeGripStyle.Show;
			this.ResumeLayout(false);
			this.PerformLayout();

		}
		#endregion

		#region Event handlers
		/// <summary>
		/// Called when the OK button is pressed
		/// </summary>
		/// <param name="sender"></param>
		/// <param name="e"></param>
		private void btnOK_Click(object sender, System.EventArgs e)
		{
			//set the new expression in the task
			expressionTask.Expression = this.tbExpression.Text;
		}

		/// <summary>
		/// called when Evaluate button is pressed
		/// </summary>
		/// <param name="sender"></param>
		/// <param name="e"></param>
		private void btnEvaluate_Click(System.Object sender, System.EventArgs e)
		{
			//Set the expression in the task
			expressionTask.Expression = tbExpression.Text;

			//Call evaluate
			string s = expressionTask.Evaluate( taskHost.VariableDispenser );

			//Set the evaluated value in the control
			sMessage.Text = s;
		}

		private void tbExpression_DragDrop(object sender, DragEventArgs e)
		{
			//retrieve the string that is being dragged from the functions
			//or variables tree
			string draggedString = e.Data.GetData(DataFormats.StringFormat) as string;
			
			//call a helper function to do the dragdrop
			BaseDtsExpressionBuilderUtils.DragDropOnTextBox(tbExpression, draggedString, e.X, e.Y, true);
		}

		private void tbExpression_DragEnter(object sender, DragEventArgs e)
		{
			//let's set the focus so that selection of the generic
			//parameters works
			tbExpression.Focus();
		}

		private void tbExpression_DragOver(object sender, DragEventArgs e)
		{
			e.Effect = DragDropEffects.Copy;
			BaseDtsExpressionBuilderUtils.DragOverTextBox(tbExpression, e.X, e.Y, true);
		}
		#endregion Event handlers
	}
}
