using System;
using System.Collections.Generic;
using System.ComponentModel;
using System.Drawing;
using System.Data;
using System.Text;
using System.Windows.Forms;
using Microsoft.DataTransformationServices.Controls;
using Microsoft.SqlServer.Dts.Design;
using Microsoft.SqlServer.Dts.Runtime;
using SSIS2K5.Samples.Tasks.StarterTask;

namespace SSIS2K5.Samples.Tasks.StarterTask
{
   #region SpecificView
   public partial class SpecificView : System.Windows.Forms.UserControl, IDTSTaskUIView
   {
      #region private members
      private SpecificNode specificNode = null;

      private System.Windows.Forms.PropertyGrid specificPropertyGrid;

      #region Init and Dispose
      public SpecificView()
      {
         // This call is required by the Windows.Forms Form Designer.
         InitializeComponent();
      }
      #endregion Init and Dispose
      #endregion

      #region IDTSTaskUIView
      /// <summary>
      /// Called when the view is about to be displayed for the first time
      /// </summary>
      /// <param name="treeHost">IDTSTaskUIHost that host the view</param>
      /// <param name="taskHost">the task that is edited by TaskUI</param>
      /// <param name="viewNode">the node in the tree associated with this view</param>
      public virtual void OnInitialize(IDTSTaskUIHost treeHost, System.Windows.Forms.TreeNode viewNode, object taskHost, object connections)
      {
         this.specificNode = new SpecificNode(taskHost as TaskHost);

         specificPropertyGrid.SelectedObject = this.specificNode;
      }

      /// <summary>
      /// is called when the OK button is pressed
      /// </summary>
      /// <param name="bViewIsValid">result of view validation</param>
      public virtual void OnValidate(ref bool bViewIsValid, ref string reason)
      {
      }

      /// <summary>
      /// called whenever the view is displaying
      /// </summary>
      public virtual void OnSelection()
      {
      }

      /// <summary>
      /// called every time the view is about to be left.
      /// </summary>
      /// <param name="bCanLeaveView">true if the view can be left</param>
      public virtual void OnLoseSelection(ref bool bCanLeaveView, ref string reason)
      {
      }

      /// <summary>
      /// called when OK button is pushed, but only if all OnValidate calls succeeded
      /// the user should set whatever properties need to be set to the task by this view
      /// </summary>
      /// <param name="taskHost">the edited task.</param>
      public virtual void OnCommit(object taskHost)
      {
      }
      #endregion IDTSTaskUIView

      #region Component Designer generated code
      /// <summary> 
      /// Required method for Designer support - do not modify 
      /// the contents of this method with the code editor.
      /// </summary>
      private void InitializeComponent()
      {
         this.specificPropertyGrid = new System.Windows.Forms.PropertyGrid();
         this.SuspendLayout();
         // 
         // specificPropertyGrid
         // 
         this.specificPropertyGrid.Anchor = ((System.Windows.Forms.AnchorStyles)((((System.Windows.Forms.AnchorStyles.Top | System.Windows.Forms.AnchorStyles.Bottom)
                     | System.Windows.Forms.AnchorStyles.Left)
                     | System.Windows.Forms.AnchorStyles.Right)));
         this.specificPropertyGrid.Location = new System.Drawing.Point(3, 0);
         this.specificPropertyGrid.Name = "specificPropertyGrid";
         this.specificPropertyGrid.PropertySort = System.Windows.Forms.PropertySort.Categorized;
         this.specificPropertyGrid.Size = new System.Drawing.Size(387, 400);
         this.specificPropertyGrid.TabIndex = 0;
         this.specificPropertyGrid.ToolbarVisible = false;
         // 
         // SpecificView
         // 
         this.Controls.Add(this.specificPropertyGrid);
         this.Name = "SpecificView";
         this.Size = new System.Drawing.Size(390, 400);
         this.ResumeLayout(false);

      }
      #endregion
   }
   #endregion

   #region SpecificNode
   /// <summary>
   /// Specific Node class corresponds to the view that is displayed when
   /// the user clicks the Specific node.
   /// </summary>
   internal class SpecificNode
   {
      internal TaskHost taskHost = null;
      private SSIS2K5.Samples.Tasks.StarterTask.StarterTask task = null;

      #region Initialization
      public SpecificNode(TaskHost taskHost)
      {
         this.taskHost = taskHost;
         this.task = taskHost.InnerObject as SSIS2K5.Samples.Tasks.StarterTask.StarterTask;
      }
      #endregion

      #region Properties

      [
      Category("Custom Properties"),
      Description("Contains the sample string property value.")
      ]
      public string StringValue
      {
         get { return task.StringValue; }
         set { task.StringValue = value; }
      }

      [
      Category("Custom Properties"),
      Description("Contains the sample int property value.")
      ]
      public int IntValue
      {
         get { return task.IntValue; }
         set { task.IntValue = value; }
      }

      #endregion Properties
   }
   #endregion SpecificNode
}
